@@ -1,7 +1,8 @@
 from th_txmessage.tx_ms_utils import TxYunMessageUtils
 import traceback
 import json
-import time;
+import time
+
 
 class TxyunMessage:
     message_deal_process = {}
@@ -48,7 +49,7 @@ class TxyunMessage:
                     if messageBody["lx"] in self.message_deal_process_after.keys():
                                 self.message_deal_process_after[messageBody["lx"]](myQueue,recv_msg)
             except Exception as e:
-                    self.m_error_deal(e);
+                    self.m_error_deal(e)
     
     def listent(self):
         while True:
@@ -56,10 +57,10 @@ class TxyunMessage:
                 myQueue = self.txyunUtils.getQueue(self.qname)
                 recv_msg = myQueue.receive_message(3)
             except Exception as e:
-                time.sleep(30)
+                # time.sleep(30)
+                pass
             else:
                 try:
-                    
                     messageBody = json.loads(recv_msg.msgBody)
                     if "lx" not in messageBody.keys() or "data" not in messageBody.keys():
                         myQueue.delete_message(recv_msg.receiptHandle)
@@ -79,9 +80,8 @@ class TxyunMessage:
                             #             break
                             #         time.sleep(0.5)
                             #         continue
-                                
                 except Exception as e:
-                    time.sleep(2);
+                    time.sleep(2)
                     traceback.print_exc()
 
     def run(self, message_type, message_body):
