@@ -1,12 +1,14 @@
 from threading import Thread
 import threading
 from time import sleep
-import traceback
-from typing_extensions import Self
+
 import pika
 import retry
 import logging
 import uuid;
+logging.basicConfig(level = logging.INFO,format = '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+logger = logging.getLogger(__name__)
+
 class rabbitmq_helper():
     message_dict:dict
     thread_stop_flag:dict;
@@ -48,9 +50,7 @@ class rabbitmq_helper():
             try:
                 ch.basic_ack(delivery_tag = method.delivery_tag)
             except Exception as e:
-                logging.log(logging.ERROR,e);
-        else:
-
+                logger.error(e);
     def heart_thread(self,conn,uuid):
         while True:
             try:
@@ -60,15 +60,19 @@ class rabbitmq_helper():
                     conn.process_data_events();
             except Exception:
                 pass;
-            sleep(10);
+            sleep(5);
 
     @retry.retry((pika.exceptions.AMQPConnectionError), delay=5, jitter=(1, 3))
     def listen(self):
+        # logging.log(logging.INFO,"程序启动");
+        logging.info("开始启动")
         credentials = pika.PlainCredentials(self.user, self.pwd)  # mq用户名和密码
         self.connection = pika.BlockingConnection(pika.ConnectionParameters(socket_timeout=10,host = self.host,port = 5672,virtual_host = '/',credentials = credentials,heartbeat=30))
         self.channel = self.connection.channel()
         self.channel.basic_qos(prefetch_count=1)
         for i in self.message_dict.keys():
                 self.channel.basic_consume(i,self.callback);
-        self.channel.start_consuming()
-        
\ No newline at end of file
+        try:
+            self.channel.start_consuming()
+        except pika.exceptions.ConnectionClosedByBroker:
+            pass
\ No newline at end of file
